utils::globalVariables(c(
  "Model", "min_value", "max_value", "na.exclude", ".data", "CodGen",
  "dev", "log_varianza", "autocorrelacion_lag1", "mean_Prod",
  "Var2", "Freq","par_list", "ID","n_individuals",":=", "DIM", "end_DIM", "episode_index", "geom_ribbon", "scale_color_manual", "start_DIM",
  "theme_bw"
))
